==> httraqt_1.2.0.orig.tar.gz: httraqt/sources/main/includes/buttonPanel.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2013 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef BUTTONPANEL_H
#define BUTTONPANEL_H

#include "ui_buttonPanel.h"


class HTTraQt;

class buttonPanel: public QWidget, public Ui_buttonsForm
{
        Q_OBJECT
    public:
        buttonPanel(QWidget *parent = 0, Qt::WFlags fl = 0);
        void translate();
        void onButtons(int n);

    public slots:
        void onHelp();
        void onStop();
        void onNext();
        void onBack();

    private:
        HTTraQt* parent;

};

#endif

==> httraqt_1.3.0.orig.tar.gz: httraqt/sources/main/includes/buttonPanel.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef BUTTONPANEL_H
#define BUTTONPANEL_H

#include "httraqt.h"
#include "ui_buttonPanel.h"


class HTTraQt;

class buttonPanel: public QWidget, public Ui_buttonsForm, public Translator
{
        Q_OBJECT
    public:
        buttonPanel(QWidget *parent = 0, Qt::WindowFlags fl = 0);
        void translateButtons();
        void onButtons(int n);

    public slots:
        void onHelp();
        void onStop();
        void onNext();
        void onBack();

    private:
        HTTraQt* parent;

};

#endif
